#!/bin/bash
# This script is helper for running various other scripts
# for exporting ElasticSearch data to S3 bucket
#
# The script takes two arguments - the Elasticsearch endpoint and the environment name (free form)

DATE=$(date +%Y-%m-%d)
TIME=$(date +%Y-%m-%d-%H-%M-%S)
DEPLOY_ENVS=("prd1ew2" "int2use2" "kctest03")

if [[ ! ${DEPLOY_ENVS[@]} =~ $ENV ]]; then
    echo "Skip the exports for ${ENV} environments ..."
    exit 1
fi

case $ENV in

  kcdev01)
    BUCKET="defense-bi-analytics-dev01"
    ;;

  int1usw2)
    BUCKET="defense-bi-analytics-dev01"
    ;;

  kctest03)
    BUCKET="defense-bi-analytics-dev01"
    ;;

  int2use2)
    BUCKET="defense-bi-analytics-cb-dev"
    ;;

  *)
    BUCKET="defense-bi-analytics-hub01"
    ;;

esac

API_KEYS_LOG=/home/docker/$TIME-api_keys_stats-$ENV.log
AVIRA_LOG=/home/docker/$TIME-avstats-$ENV.log
SENSOR_LOG=/home/docker/$TIME-org_stats-$ENV.log

# Elasticsearch endpoint
#echo "The ES cluster endpoint: $1"

# run export script for api-keys-stats
node app-apikeystats.js $1 443 > $API_KEYS_LOG

if [ -f $API_KEYS_LOG ]; then
  # copy stats file to s3
  aws s3 cp $API_KEYS_LOG s3://$BUCKET/deployment_stats/api_key_stats/$DATE/
fi

# run export script for avira-stats
node app-avstats.js $1 443 > $AVIRA_LOG

if [ -f $AVIRA_LOG ]; then
  aws s3 cp $AVIRA_LOG s3://$BUCKET/deployment_stats/avstats/$DATE/
fi

# run export script for sensor-stats
node app-orgstats.js $1 443 > $SENSOR_LOG

if [ -f $SENSOR_LOG ]; then
  aws s3 cp $SENSOR_LOG s3://$BUCKET/deployment_stats/sensor_stats/$DATE/
fi
